@@ -22,11 +22,10 @@
 #include <QTextStream>
 #include <QRegExp>
 #include <QFileInfo>
+#include <QStandardPaths>
 
 #include "kmenuedit_debug.h"
-#include <KGlobal>
 #include <KLocalizedString>
-#include <KStandardDirs>
 
 const QString MenuFile::MF_MENU = QStringLiteral("Menu");
 const QString MenuFile::MF_PUBLIC_ID = QStringLiteral("-//freedesktop//DTD Menu 1.0//EN");
@@ -186,6 +185,18 @@ QDomElement MenuFile::findMenu(QDomElement elem, const QString &menuName, bool c
     }
 }
 
+static QString relativeToDesktopDirsLocation(const QString &file)
+{
+    const QString canonical = QFileInfo(file).canonicalFilePath();
+    const QStringList dirs = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+    for (const QString &dir : dirs) {
+        const QString base = dir + QLatin1String("/desktop-directories");
+        if (canonical.startsWith(base))
+            return canonical.mid(base.length()+1);
+    }
+    return QString();
+}
+
 static QString entryToDirId(const QString &path)
 {
     // See also KDesktopFile::locateLocal
@@ -193,7 +204,7 @@ static QString entryToDirId(const QString &path)
     if (QFileInfo(path).isAbsolute()) {
         // XDG Desktop menu items come with absolute paths, we need to
         // extract their relative path and then build a local path.
-        local = KGlobal::dirs()->relativeLocation("xdgdata-dirs", path);
+        local = relativeToDesktopDirsLocation(path);
     }
 
     if (local.isEmpty() || local.startsWith(QLatin1Char('/'))) {
@@ -320,7 +331,7 @@ void MenuFile::setLayout(const QString &menuName, const QStringList &layout)
             mergeNode.setAttribute(QStringLiteral("type"), QStringLiteral("all"));
             layoutNode.appendChild(mergeNode);
         } else if (li.endsWith(QLatin1Char('/'))) {
-            li.truncate(li.length()-1);
+            li.chop(1);
             QDomElement menuNode = m_doc.createElement(MF_MENUNAME);
             menuNode.appendChild(m_doc.createTextNode(li));
             layoutNode.appendChild(menuNode);
@@ -436,7 +447,7 @@ QString MenuFile::uniqueMenuName(const QString &menuName, const QString &newMenu
 
     QString result = newMenu;
     if (result.endsWith(QLatin1Char('/'))) {
-        result.truncate(result.length()-1);
+        result.chop(1);
     }
 
     QRegExp r(QStringLiteral("(.*)(?=-\\d+)"));
