@@ -41,7 +41,6 @@
 #include <KBuildSycocaProgressDialog>
 #include "kmenuedit_debug.h"
 #include <KDesktopFile>
-#include <KGlobal>
 #include <KIconLoader>
 #include <KInputDialog>
 #include <KLocalizedString>
@@ -50,11 +49,10 @@
 #include <KServiceGroup>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KStandardDirs>
-#include <kio/netaccess.h>
 #include <KUrlMimeData>
 #include <KUrl>
 #include <KStringHandler>
+#include <QStandardPaths>
 
 #include "menufile.h"
 #include "menuinfo.h"
@@ -285,7 +283,7 @@ TreeView::TreeView(KActionCollection *ac, QWidget *parent)
     connect(this, &QTreeWidget::currentItemChanged,
             this, &TreeView::itemSelected);
 
-    m_menuFile = new MenuFile(KStandardDirs::locateLocal("xdgconf-menu", QStringLiteral("applications-kmenuedit.menu")));
+    m_menuFile = new MenuFile(QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1String("/menus/") + QStringLiteral("applications-kmenuedit.menu"));
     m_rootFolder = new MenuFolderInfo;
     m_separator = new MenuSeparatorInfo;
 }
@@ -444,9 +442,9 @@ TreeItem *TreeView::createTreeItem(TreeItem *parent, QTreeWidgetItem *after, Men
 
     if (m_detailedMenuEntries && entryInfo->description.length() != 0) {
         if (m_detailedEntriesNamesFirst) {
-            name = entryInfo->caption + QStringLiteral(" (") + entryInfo->description + QLatin1Char(')');
+            name = entryInfo->caption + QLatin1String(" (") + entryInfo->description + QLatin1Char(')');
         } else {
-            name = entryInfo->description + QStringLiteral(" (") + entryInfo->caption + QLatin1Char(')');
+            name = entryInfo->description + QLatin1String(" (") + entryInfo->caption + QLatin1Char(')');
         }
     } else {
         name = entryInfo->caption;
@@ -500,7 +498,7 @@ void TreeView::fillBranch(MenuFolderInfo *folderInfo, TreeItem *parent)
 }
 TreeItem *TreeView::expandPath(TreeItem *item, const QString &path)
 {
-    int i = path.indexOf(QStringLiteral("/"));
+    int i = path.indexOf(QLatin1String("/"));
     QString subMenu = path.left(i+1);
     QString restMenu = path.mid(i+1);
 
@@ -546,7 +544,7 @@ void TreeView::selectMenu(const QString &menu)
     }
 
     TreeItem *item = nullptr;
-    int i = restMenu.indexOf(QStringLiteral("/"));
+    int i = restMenu.indexOf(QLatin1String("/"));
     QString subMenu = restMenu.left(i+1);
     restMenu = restMenu.mid(i+1);
 
@@ -679,9 +677,9 @@ void TreeView::currentDataChanged(MenuEntryInfo *entryInfo)
 
     if (m_detailedMenuEntries && !entryInfo->description.isEmpty()) {
         if (m_detailedEntriesNamesFirst) {
-            name = entryInfo->caption + QStringLiteral(" (") + entryInfo->description + QLatin1Char(')');
+            name = entryInfo->caption + QLatin1String(" (") + entryInfo->description + QLatin1Char(')');
         } else {
-            name = entryInfo->description + QStringLiteral(" (") + entryInfo->caption + QLatin1Char(')');
+            name = entryInfo->description + QLatin1String(" (") + entryInfo->caption + QLatin1Char(')');
         }
     } else {
         name = entryInfo->caption;
@@ -691,89 +689,6 @@ void TreeView::currentDataChanged(MenuEntryInfo *entryInfo)
     item->setIcon(0, QIcon::fromTheme(entryInfo->icon));
 }
 
-QStringList TreeView::fileList(const QString &rPath)
-{
-    QString relativePath = rPath;
-
-    // truncate "/.directory"
-    int pos = relativePath.lastIndexOf(QLatin1String("/.directory"));
-    if (pos > 0) {
-        relativePath.truncate(pos);
-    }
-
-    QStringList filelist;
-
-    // loop through all resource dirs and build a file list
-    const QStringList resdirlist = KGlobal::dirs()->resourceDirs("apps");
-    for (QStringList::ConstIterator it = resdirlist.constBegin(); it != resdirlist.constEnd(); ++it) {
-        QDir dir((*it) + QLatin1Char('/') + relativePath);
-        if (!dir.exists()) {
-            continue;
-        }
-
-        dir.setFilter(QDir::Files);
-        dir.setNameFilters(QStringList() << QStringLiteral("*.desktop;*.kdelnk"));
-
-        // build a list of files
-        const QStringList files = dir.entryList();
-        for (QStringList::ConstIterator it = files.constBegin(); it != files.constEnd(); ++it) {
-            // does not work?!
-            //if (filelist.contains(*it)) continue;
-
-            if (relativePath.isEmpty()) {
-                filelist.removeAll(*it); // hack
-                filelist.append(*it);
-            } else {
-                filelist.removeAll(relativePath + QLatin1Char('/') + *it); //hack
-                filelist.append(relativePath + QLatin1Char('/') + *it);
-            }
-        }
-    }
-    return filelist;
-}
-
-QStringList TreeView::dirList(const QString &rPath)
-{
-    QString relativePath = rPath;
-
-    // truncate "/.directory"
-    int pos = relativePath.lastIndexOf(QLatin1String("/.directory"));
-    if (pos > 0) {
-        relativePath.truncate(pos);
-    }
-
-    QStringList dirlist;
-
-    // loop through all resource dirs and build a subdir list
-    const QStringList resdirlist = KGlobal::dirs()->resourceDirs("apps");
-    for (QStringList::ConstIterator it = resdirlist.constBegin(); it != resdirlist.constEnd(); ++it) {
-        QDir dir((*it) + QLatin1Char('/') + relativePath);
-        if (!dir.exists()) {
-            continue;
-        }
-        dir.setFilter(QDir::Dirs);
-
-        // build a list of subdirs
-        const QStringList subdirs = dir.entryList();
-        for (QStringList::ConstIterator it = subdirs.constBegin(); it != subdirs.constEnd(); ++it) {
-            if ((*it) == QLatin1String(".") || (*it) == QLatin1String("..")) {
-                continue;
-            }
-            // does not work?!
-            // if (dirlist.contains(*it)) continue;
-
-            if (relativePath.isEmpty()) {
-                dirlist.removeAll(*it); //hack
-                dirlist.append(*it);
-            } else {
-                dirlist.removeAll(relativePath + QLatin1Char('/') + *it); //hack
-                dirlist.append(relativePath + QLatin1Char('/') + *it);
-            }
-        }
-    }
-    return dirlist;
-}
-
 Qt::DropActions TreeView::supportedDropActions() const
 {
     return Qt::CopyAction | Qt::MoveAction;
@@ -849,14 +764,14 @@ static QString createDirectoryFile(const QString &file, QStringList *excludeList
         }
 
         if (!excludeList->contains(result)) {
-            if (KStandardDirs::locate("xdgdata-dirs", result).isEmpty()) {
+            if (QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("desktop-directories/") + result).isEmpty()) {
                 break;
             }
         }
         i++;
     }
     excludeList->append(result);
-    result = KStandardDirs::locateLocal("xdgdata-dirs", result);
+    result = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/desktop-directories/") + result;
     return result;
 }
 
@@ -1855,19 +1770,24 @@ void TreeView::restoreMenuSystem()
     if (KMessageBox::warningYesNo(this, i18n("Do you want to restore the system menu? Warning: This will remove all custom menus.")) == KMessageBox::No) {
         return;
     }
-    QString kmenueditfile = KStandardDirs::locateLocal("xdgconf-menu", QStringLiteral("applications-kmenuedit.menu"));
+    const QString kmenueditfile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1String("/menus/applications-kmenuedit.menu");
     if (QFile::exists(kmenueditfile)) {
         if (!QFile::remove(kmenueditfile)) {
             qCWarning(KMENUEDIT_LOG)<<"Could not delete "<<kmenueditfile;
         }
     }
 
-    QString xdgdir = KGlobal::dirs()->KStandardDirs::localxdgdatadir();
-    if (!KIO::NetAccess::del(QUrl::fromLocalFile(xdgdir + QStringLiteral("/applications")), this)) {
-        qCWarning(KMENUEDIT_LOG)<<"Could not delete dir :"<<(xdgdir+ QStringLiteral("/applications"));
+    const QString xdgappsdir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/applications");
+    if (QFileInfo(xdgappsdir).isDir()) {
+        if (!QDir(xdgappsdir).removeRecursively()) {
+            qCWarning(KMENUEDIT_LOG)<<"Could not delete dir :" << xdgappsdir;
+        }
     }
-    if (!KIO::NetAccess::del(QUrl::fromLocalFile(xdgdir + QStringLiteral("/desktop-directories")), this)) {
-        qCWarning(KMENUEDIT_LOG)<<"Could not delete dir :"<<(xdgdir + QStringLiteral("/desktop-directories"));
+    const QString xdgdesktopdir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/desktop-directories");
+    if (QFileInfo(xdgdesktopdir).isDir()) {
+        if (!QDir(xdgdesktopdir).removeRecursively()) {
+            qCWarning(KMENUEDIT_LOG)<<"Could not delete dir :" << xdgdesktopdir;
+        }
     }
 
     KBuildSycocaProgressDialog::rebuildKSycoca(this);
